#
# Copyright (c) 2020 Xilinx, Inc. All rights reserved.
# SPDX-License-Identifier: MIT
#

from roast.machines.zynqmp import *

dtb_dtg = "zcu216-reva"
silicon = "zu49-prod"
uboot_devicetree = "zynqmp-zcu216-revA"

PLNX_BSP = "xilinx-zcu216-v{version}-final.bsp"
plnx_proj = "xilinx-zcu216-{version}"
